@@ -140,7 +140,7 @@ condition_code_t psyco_vsource_cc(Source source)
 
 #else /* if !HAVE_CCREG */
 
-/* psyco_vinfo_condition() defined in iencoding.c */
+# error "this was meant for ivm, but now ivm also defines HAVE_CCREG."
 
 #endif /* HAVE_CCREG */
 
@@ -1136,9 +1136,8 @@ void psyco_codegen_init(void)
   int i;
   for (i=0; i<CC_TOTAL; i++)
     {
-      /* the condition codes cannot be passed across function calls,
-         hence the NW_FORCE argument */
-      INIT_SVIRTUAL(cc_functions_table[i], generic_computed_cc, 0, NW_FORCE);
+      /* the condition codes cannot be passed across function calls */
+      INIT_SVIRTUAL_NOCALL(cc_functions_table[i], generic_computed_cc, 0);
     }
 #endif
   psyco_nonfixed_promotion.header.compute_fn = &computed_promotion;
