@@ -4,6 +4,7 @@ import re
 explicitnumber = {
     '0x010100f0': '1.1.1',   # bugfix release, no change in hex version
     '0x010200f0': '1.2',
+    '0x010300f0': '1.3',
     }
 
 FILES = {
@@ -15,6 +16,7 @@ FILES = {
     '../../my/psyco/site/content/index.rst': re.compile(r'`Psyco ([0-9.]+)@'),
     '../../my/psyco/site/content/download.rst': re.compile(r'Current version is ([0-9.]+)'),
     '../../my/psyco/site/content/./download.rst': re.compile(r'Download Release ([0-9.]+)'),
+    '../../my/psyco/site/content/doc.rst': re.compile(r'Psyco release ([0-9.]+)'),
     '../README.txt': re.compile(r'VERSION ([0-9.]+)'),
     }
 
